:mod:`lck.django.score.templatetags.lckd_score`
===============================================

.. automodule:: lck.django.score.templatetags.lckd_score

Functions
---------

.. autofunction:: get_score_value

.. autofunction:: render_score
